package com.ynet.life.controller;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.log.GENELog;
import com.ynet.gene.session.GENESession;
import com.ynet.gene.session.InvalidSessionException;
import com.ynet.gene.session.Session;
import com.ynet.gene.web.servlet.ModelAndView;
import com.ynet.gene.web.servlet.mvc.BizLogicException;
import com.ynet.gene.web.servlet.mvc.GENEFlowExecuteResult;
import com.ynet.gene.web.servlet.mvc.GENESessionRequestController;
import com.ynet.gene.web.servlet.mvc.InvalidInputException;
import com.ynet.gene.web.servlet.view.View;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.TEntity;
import com.ynet.life.base.Trace;
import com.ynet.life.base.logon.LifeLogonManager;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.mvc.MVCXmlView;
import com.ynet.life.mvc.XMLView;
import java.net.InetAddress;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.collections.LRUMap;
import org.apache.commons.lang.StringUtils;
import org.w3c.dom.Document;

/* loaded from: com_ynet_life_controller.jar:com/ynet/life/controller/LifeEstablishSessionController.class */
public class LifeEstablishSessionController extends GENESessionRequestController {
    private static boolean isServerAddressInitialized = false;
    private static String isStrengthVerify = "singleSign";
    private String sessionContextName;
    protected String sessionIdFieldName = "sessionId";
    private boolean isSingleLogonCheck = true;

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v33, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v4, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r0v5, types: [java.lang.Throwable] */
    public ModelAndView doRequest(HttpServletRequest request, HttpServletResponse response) throws Exception {
        ModelAndView result;
        initServerAddress(request);
        if (this.openMonitor) {
            this.accessInfo.newAccess();
        }
        ?? method = request.getMethod();
        try {
            if (this.flowDef == null) {
                Map model = new HashMap();
                new ModelAndView(model, getView());
            }
            if (getView() != null && !"POST".equalsIgnoreCase(method)) {
                Map model2 = new HashMap();
                result = new ModelAndView(model2, getView());
            } else {
                result = executeTheFlow(request, response);
            }
            Context context = (Context) result.getModel().get(GENEConstance.ATTR_CONTEXT);
            String sessionId = (String) context.getDataValue(this.sessionIdFieldName);
            Session userSession = (Session) this.sessionManager.getSessions().get(sessionId);
            Context sessionContext = (Context) userSession.getAttribute(GENEConstance.ATTR_CONTEXT);
            setSessionTimeout(userSession, context);
            Map<String, String> flowMap = Collections.synchronizedMap(new LRUMap(10));
            sessionContext.put("windowsID_map", flowMap);
            if (context.containsKey(isStrengthVerify)) {
                String signFlag = (String) context.getDataValue(isStrengthVerify);
                if ("isSign".equals(signFlag)) {
                    this.sessionManager.removeSession((String) sessionContext.getDataValue(this.sessionIdFieldName));
                }
            }
            method = this.isSingleLogonCheck;
            if (method != 0) {
            }
            return result;
        } catch (Exception e) {
            throw method;
        }
    }

    protected ModelAndView executeTheFlow(HttpServletRequest request, HttpServletResponse response) throws Exception {
        Context sessionContext = null;
        Session session = initSession(request, response);
        if (session != null) {
            sessionContext = (Context) session.getAttribute(GENEConstance.ATTR_CONTEXT);
        }
        Map model = new HashMap();
        if (this.flowDef == null) {
            View retView = this.inputView;
            if (this.outputViews != null && this.outputViews.size() > 0) {
                View view = (View) this.outputViews.get("default");
                retView = view;
                if (view == null) {
                    retView = (View) this.outputViews.get("output");
                }
                if (retView == null) {
                    retView = (View) this.outputViews.entrySet().toArray()[0];
                }
            }
            if (retView == null) {
                throw new GENEException("required to execute flow, but no flow defined, and no input/out view defined! " + toString());
            }
            return new ModelAndView(model, retView);
        }
        GENEFlowExecuteResult result = executeGENELogic(sessionContext, request, response);
        result.context.put(TEntity.appKeyFieldname, (String) sessionContext.getDataValue(this.sessionIdFieldName));
        model.put(GENEConstance.ATTR_CONTEXT, result.context);
        Context context = result.context;
        model.put(GENEConstance.ATTR_FLOW_OUTPUT, result.flow.getOutput(this.flowDef.getOpId()));
        if (result.e != null) {
            if (result.e instanceof InvalidInputException) {
                result.e.setModel(model);
                throw result.e;
            }
            if (result.e instanceof InvalidSessionException) {
                this.sessionManager.removeSession(session);
                throw new BizLogicException(model, result.e);
            }
            throw new BizLogicException(model, result.e);
        }
        return new ModelAndView(model, new XMLView());
    }

    protected void initServerAddress(HttpServletRequest request) throws Exception {
        if (!isServerAddressInitialized) {
            try {
                LifeLogonManager.setServerAddress(String.valueOf(InetAddress.getLocalHost().getHostAddress()) + ":" + request.getLocalPort());
            } catch (Exception unused) {
                Trace.logWarning("LifeCore", "Initialize runtime server address error, so keeps [settings.xml#LifeSettings.serverAddress]'s init value");
            }
            isServerAddressInitialized = true;
        }
    }

    protected Session initSession(HttpServletRequest request, HttpServletResponse response) throws Exception {
        if (this.sessionManager == null) {
            Trace.logError("LifeSession", "Session manager not set for the GENE component factory! please set it in GENEServletContext.xml");
            throw new GENEException("Session manager not set for the GENE component factory! please set it in GENEServletContext.xml");
        }
        Session session = this.sessionManager.getSession(request, response, true);
        Context sessionContext = this.geneFactory.getContext((Document) null, this.sessionContextName);
        try {
            sessionContext.setDataValue(this.sessionIdFieldName, session.getId());
        } catch (Exception e) {
            Trace.logWarning("LifeSession", "Session controller: Data field [" + this.sessionIdFieldName + "] not found in session context! ", e);
        }
        session.setAttribute(GENEConstance.ATTR_CONTEXT, sessionContext);
        return session;
    }

    private void setLanguage(HttpServletRequest request, Context sessionContext) throws TranFailException {
        if (sessionContext == null) {
            return;
        }
        try {
            String parameter = request.getParameter("language");
            String language = parameter;
            if (StringUtils.isBlank(parameter)) {
                Cookie[] cookies = request.getCookies();
                int i = 0;
                while (true) {
                    if (i >= cookies.length) {
                        break;
                    }
                    String cookieName = cookies[i].getName();
                    if (!"language".equals(cookieName)) {
                        i++;
                    } else {
                        language = cookies[i].getValue();
                        break;
                    }
                }
            }
            StringUtils.isBlank(language);
            sessionContext.setDataValue("session_language", LifeClientRequest.getClientIP(request));
        } catch (Exception ex) {
            Trace.logError("LifeSession", "用户登录语种获取出错", ex);
            throw new TranFailException("用户登录语种获取出错", ex);
        }
    }

    protected void singleLogonCheck(Context sessionContext) throws TranFailException {
        if (sessionContext != null) {
            String sessionId = null;
            try {
                sessionId = (String) sessionContext.getDataValue(this.sessionIdFieldName);
            } catch (GENEException ex) {
                Trace.logWarning("LifeSession", ex.getMessage(), ex);
            }
            LifeLogonManager.addUser(sessionContext, sessionId, this.sessionManager);
        }
    }

    public ModelAndView handleException(HttpServletRequest request, HttpServletResponse response, Exception e) {
        Context tmpCtx;
        try {
            GENESession session = (GENESession) request.getAttribute(GENEConstance.ATTR_SESSION);
            if (session != null) {
                this.sessionManager.removeSession(session);
                if (session != null && (tmpCtx = (Context) session.getAttribute(GENEConstance.ATTR_CONTEXT)) != null) {
                    if (e instanceof GENEException) {
                        String errorCode = ((GENEException) e).getErrorCode();
                        if (LifeStandard.getBankSettingsValue("monitorException").indexOf(errorCode) >= 0) {
                            tmpCtx.getDataValue("session_customerId");
                            if (tmpCtx.containsKey("session_userId")) {
                                tmpCtx.getDataValue("session_userId");
                            }
                        }
                    }
                    tmpCtx.terminate();
                }
            }
        } catch (Exception ee) {
            GENELog.log(GENEConstance.GENE_MVC, GENELog.WARNING, 0, "Session controller: terminat session context failure! ", ee);
        }
        Map model = new HashMap();
        model.put(GENEConstance.ATTR_EXCEPTION, e);
        return new ModelAndView(model, new MVCXmlView());
    }

    protected void setSessionTimeout(Session session, Context sessionContext) {
    }

    public String getSessionContextName() {
        return this.sessionContextName;
    }

    public void setSessionContextName(String sessionContextName) {
        this.sessionContextName = sessionContextName;
    }

    public void setSessionIdFieldName(String sessionIdFieldName) {
        this.sessionIdFieldName = sessionIdFieldName;
    }

    public void setIsSingleLogonCheck(boolean isSingleLogonCheck) {
        this.isSingleLogonCheck = isSingleLogonCheck;
    }
}
